@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 import argparse
 import logging
 import sys
-from typing import Optional, Sequence
+from typing import Optional
 
 import annofabcli.annotation.subcommand_annotation
 import annofabcli.annotation_specs.subcommand_annotation_specs
@@ -13,6 +15,8 @@ import annofabcli.input_data.subcommand_input_data
 import annofabcli.inspection_comment.subcommand_inspection_comment
 import annofabcli.instruction.subcommand_instruction
 import annofabcli.job.subcommand_job
+import annofabcli.my_account.subcommand_my_account
+import annofabcli.organization.subcommand_organization
 import annofabcli.organization_member.subcommand_organization_member
 import annofabcli.project.subcommand_project
 import annofabcli.project_member.subcommand_project_member
@@ -26,7 +30,7 @@ import annofabcli.task_history_event.subcommand_task_history_event
 logger = logging.getLogger(__name__)
 
 
-def main(arguments: Optional[Sequence[str]] = None):
+def main(arguments: Optional[list[str]] = None):
     """
     annofabcliコマンドのメイン処理
     注意： `deprecated`なツールは、サブコマンド化しない。
@@ -45,7 +49,10 @@ def main(arguments: Optional[Sequence[str]] = None):
     if hasattr(args, "subcommand_func"):
         try:
             annofabcli.common.cli.load_logging_config_from_args(args)
-            logger.info(f"sys.argv='{sys.argv}'")
+            argv = sys.argv
+            if arguments is not None:
+                argv = ["annofabcli"] + list(arguments)
+            logger.info(f"argv={argv}")
             args.subcommand_func(args)
         except Exception as e:
             logger.exception(e)
@@ -72,6 +79,8 @@ def create_parser() -> argparse.ArgumentParser:
     annofabcli.inspection_comment.subcommand_inspection_comment.add_parser(subparsers)
     annofabcli.instruction.subcommand_instruction.add_parser(subparsers)
     annofabcli.job.subcommand_job.add_parser(subparsers)
+    annofabcli.my_account.subcommand_my_account.add_parser(subparsers)
+    annofabcli.organization.subcommand_organization.add_parser(subparsers)
     annofabcli.organization_member.subcommand_organization_member.add_parser(subparsers)
     annofabcli.project.subcommand_project.add_parser(subparsers)
     annofabcli.project_member.subcommand_project_member.add_parser(subparsers)
