@@ -5,13 +5,15 @@ import annofabcli
 import annofabcli.common.cli
 import annofabcli.task.cancel_acceptance
 import annofabcli.task.change_operator
+import annofabcli.task.change_status_to_break
 import annofabcli.task.complete_tasks
 import annofabcli.task.copy_tasks
 import annofabcli.task.delete_tasks
 import annofabcli.task.download_task_json
+import annofabcli.task.list_all_tasks
+import annofabcli.task.list_all_tasks_added_task_history
 import annofabcli.task.list_tasks
 import annofabcli.task.list_tasks_added_task_history
-import annofabcli.task.list_tasks_with_json
 import annofabcli.task.put_tasks
 import annofabcli.task.put_tasks_by_count
 import annofabcli.task.reject_tasks
@@ -25,13 +27,15 @@ def parse_args(parser: argparse.ArgumentParser):
     # サブコマンドの定義
     annofabcli.task.cancel_acceptance.add_parser(subparsers)
     annofabcli.task.change_operator.add_parser(subparsers)
+    annofabcli.task.change_status_to_break.add_parser(subparsers)
     annofabcli.task.complete_tasks.add_parser(subparsers)
     annofabcli.task.copy_tasks.add_parser(subparsers)
     annofabcli.task.delete_tasks.add_parser(subparsers)
     annofabcli.task.download_task_json.add_parser(subparsers)
     annofabcli.task.list_tasks.add_parser(subparsers)
-    annofabcli.task.list_tasks_with_json.add_parser(subparsers)
     annofabcli.task.list_tasks_added_task_history.add_parser(subparsers)
+    annofabcli.task.list_all_tasks.add_parser(subparsers)
+    annofabcli.task.list_all_tasks_added_task_history.add_parser(subparsers)
     annofabcli.task.put_tasks.add_parser(subparsers)
     annofabcli.task.put_tasks_by_count.add_parser(subparsers)
     annofabcli.task.reject_tasks.add_parser(subparsers)
